slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPJDGetProjection

Returns the type of projection used by the Jacobi-Davidson solver.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPJDGetProjection(PEP pep,PEPJDProjection *proj)

Not Collective

### Input Parameter

| pep | - the eigenproblem solver context

### Output Parameter

| proj | - the type of projection

### See Also

PEPJDSetProjection()

### Level

advanced

### Location

src/pep/impls/jd/pjd.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages